agentle.agents.knowledge
========================

.. automodule:: agentle.agents.knowledge

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   document_knowledge
   static_knowledge
   url_knowledge
